@@ -10,21 +10,21 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.3.18"
+#define MARIADB_CLIENT_VERSION_STR	"10.3.22"
 #define MARIADB_BASE_VERSION		"mariadb-10.3"
-#define MARIADB_VERSION_ID		100318
+#define MARIADB_VERSION_ID		100322
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100318
-#define MYSQL_SERVER_VERSION            "10.3.18-MariaDB"
+#define MYSQL_VERSION_ID                100322
+#define MYSQL_SERVER_VERSION            "10.3.22-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.4"
-#define MARIADB_PACKAGE_VERSION_ID 30104
+#define MARIADB_PACKAGE_VERSION "3.1.7"
+#define MARIADB_PACKAGE_VERSION_ID 30107
 #define MARIADB_SYSTEM_TYPE "OpenBSD"
-#define MARIADB_MACHINE_TYPE "mips64"
-#define MARIADB_PLUGINDIR "/usr/local//usr/local/lib/mysql/plugin"
+#define MARIADB_MACHINE_TYPE "i386"
+#define MARIADB_PLUGINDIR "/usr/local/lib/mysql/plugin"
 
 /* mysqld compile time options */
 #ifndef MYSQL_CHARSET
